@@ -8,9 +8,9 @@ from typing import TYPE_CHECKING
 import orjson
 import pydantic
 
-from .gamemode import Gamemode
 from .mods import Mods
 
+
 if TYPE_CHECKING:
     from typing import Any
 
@@ -31,9 +31,9 @@ class BaseModel(pydantic.BaseModel):
         allow_population_by_field_name = True
         json_loads = orjson.loads
         json_dumps = orjson_dumps
+
         json_encoders = {
             Mods: str,
-            Gamemode: str,
         }
 
 
