@@ -114,15 +114,30 @@ class Mod(IntEnum):
 
     @classmethod
     def from_type(cls, __o: object) -> Mod:
+        """Get a Mod from a string or int.
+
+        :param __o: The string or int to get the Mod from
+        :type __o: object
+        :return: The Mod
+        :rtype: Mod
+        :raises ValueError: If the Mod does not exist
+        """
+        from .lazer import LazerMod  # Lazy import to avoid circular imports
+
         if isinstance(__o, cls):
             return __o
+        if isinstance(__o, LazerMod):
+            try:
+                return cls.from_type(__o.acronym)
+            except ValueError:
+                return cls.NoMod
         for mod in list(Mod):
             if __o == mod.short_name or __o == mod.bitmask:
                 return mod
         raise ValueError(f"Mod {__o!r} does not exist.")
 
     @classmethod
-    def _missing_(cls, query: object) -> Mod:
+    def _missing_(cls, query: object) -> Any:
         return cls.from_type(query)
 
 
@@ -137,7 +152,7 @@ class Mods(UserList):
             return
         if isinstance(mods, str):  # string of mods
             mods = [mods[i : i + 2] for i in range(0, len(mods), 2)]
-        if isinstance(mods, list):  # List of Mod types
+        if isinstance(mods, list) or isinstance(mods, Mods):  # List of Mod types
             self.data = [Mod(mod) for mod in mods]  # type: ignore
 
     @property
@@ -188,10 +203,6 @@ class Mods(UserList):
     def __get_validators__(cls) -> Generator:
         yield cls._validate
 
-    @classmethod
-    def __modify_schema__(cls, field_schema):  # type: ignore
-        pass  # Genuinely not sure about implementing this
-
     @classmethod
     def _validate(cls, v: object) -> Mods:
         if not isinstance(v, (list, str, int)):
